<!-- markdownlint-disable -->

<a href="..\..\qtstrap\utils\__init__.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `utils`




**Global Variables**
---------------
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**




---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
